"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = featureLoader;

var React = _interopRequireWildcard(require("react"));

var _reactRedux = require("react-redux");

var _reduxFeatures = require("redux-features");

var _reselect = require("reselect");

var _lodash = require("lodash");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function featureLoader(options) {
  const {
    getFeatures,
    getFeatureStates,
    featureId,
    render
  } = (0, _lodash.defaults)({}, options, {
    getFeatures: state => state ? state.features : undefined,
    getFeatureStates: state => state ? state.featureStates : undefined
  });
  const mapStateToProps = (0, _reselect.createSelector)(getFeatures, getFeatureStates, (features = {}, featureStates = {}) => ({
    feature: features[featureId],
    featureState: featureStates[featureId]
  }));

  function mergeProps({
    feature,
    featureState
  }, {
    dispatch
  }, props) {
    return {
      dispatch,
      featureState,
      children: render ? render({
        feature,
        featureState,
        props
      }) : null
    };
  }

  class FeatureLoader extends React.Component {
    componentWillMount() {
      const {
        featureState,
        dispatch
      } = this.props;
      if (featureState === 'NOT_LOADED') dispatch((0, _reduxFeatures.loadFeature)(featureId));
    }

    render() {
      return this.props.children;
    }

  }

  return (0, _reactRedux.connect)(mapStateToProps, null, mergeProps)(FeatureLoader);
}